@@ -19,9 +19,8 @@ sub _bless_dbo {
 sub _get_table_schema {
     my $me = shift;
     my $schema = shift; # Not used
-    my $table = my $q_table = shift;
+    my $table = shift;
     ouch 'No table name supplied' unless defined $table and length $table;
-
     return;
 }
 
@@ -49,7 +48,7 @@ sub _get_table_info {
     }
     $h{Columns} = [ sort { $h{Column_Idx}{$a} cmp $h{Column_Idx}{$b} } keys %{$h{Column_Idx}} ];
     $h{PrimaryKeys} = [];
-    $me->{TableInfo}{$schema // ''}{$table} = \%h;
+    $me->{TableInfo}{defined $schema ? $schema : ''}{$table} = \%h;
 }
 
 1;
