@@ -6,13 +6,28 @@ use warnings;
 
 use overload '**' => \&column, fallback => 1;
 
-=head2 config
+=head1 NAME
 
-  $table_setting = $dbo->config($option)
-  $dbo->config($option => $table_setting)
+DBIx::DBO::Table - An OO interface to SQL queries and results.  Encapsulates a table in an object.
 
-Get or set the global or dbo config settings.
-When setting an option, the previous value is returned.
+=head1 SYNOPSIS
+
+  # Create a Table object
+  my $table = $dbo->table('my_table');
+
+  # Get a column reference
+  my $column = $table ** 'employee_id';
+
+  # Quickly display my employee id
+  print $table->fetch_value('employee_id', name => 'Vernon');
+
+  # Insert a new row into the table
+  $table->insert(employee_id => 007, name => 'James Bond');
+
+  # Remove rows from the table where the name IS NULL
+  $table->delete(name => undef);
+
+=head1 METHODS
 
 =head2 dbh
 
@@ -32,14 +47,6 @@ This provides access to DBI C<do> method. It defaults to using the read-write DB
 
 =cut
 
-sub config {
-    my $me = shift;
-    my $opt = shift;
-    my $val = $me->{Config}{$opt} // $me->{DBO}->config($opt);
-    $me->{Config}{$opt} = shift if @_;
-    return $val;
-}
-
 sub _new {
     my ($proto, $dbo, $table) = @_;
     my $class = ref($proto) || $proto;
@@ -69,7 +76,7 @@ sub _showing {
 
 sub _quoted_name {
     my $me = shift;
-    $me->{_quoted_name} //= $me->_qi(@$me{qw(Schema Name)});
+    defined $me->{_quoted_name} ? $me->{_quoted_name} : ($me->{_quoted_name} = $me->_qi(@$me{qw(Schema Name)}));
 }
 
 =head2 column
@@ -85,7 +92,7 @@ sub column {
     my ($me, $col) = @_;
     ouch 'Invalid column '.$me->_qi($col).' in table '.$me->_quoted_name
         unless exists $me->{Column_Idx}{$col};
-    $me->{Column}{$col} //= bless [ $me, $col ], 'DBIx::DBO::Column';
+    defined $me->{Column}{$col} ? $me->{Column}{$col} : ($me->{Column}{$col} = bless [$me, $col], 'DBIx::DBO::Column');
 }
 
 =head2 fetch_value
@@ -198,6 +205,24 @@ sub delete {
     $me->do($sql, undef, @bind);
 }
 
+=head2 config
+
+  $table_setting = $dbo->config($option)
+  $dbo->config($option => $table_setting)
+
+Get or set the C<DBIx::DBO::Table> config settings.
+When setting an option, the previous value is returned.
+
+=cut
+
+sub config {
+    my $me = shift;
+    my $opt = shift;
+    my $val = defined $me->{Config}{$opt} ? $me->{Config}{$opt} : $me->{DBO}->config($opt);
+    $me->{Config}{$opt} = shift if @_;
+    return $val;
+}
+
 sub DESTROY {
     undef %{$_[0]};
 }
